@@ -124,7 +124,7 @@ def sections_to_text(doc, sections, citations: ArticleCitations, params):
         for section in sections:
             start = sum(map(len, text_buf))
             bstart = start
-            text_buf.append(section.name + "\n")
+            text_buf.append((section.name if section.name is not None else "") + "\n")
             end = sum(map(len, text_buf))
             sentences.append(Sentence(start=start, end=end))
             if section.paragraphs:
